@@ -32,11 +32,8 @@ class PlotMax:
     a union framework of plot
 
     args:
-        figsize: the size of figure, default (16,5)
-        figtitle: the title of figure, default ''
         capacity: the max curve capacity for each subfigure
         count_cut: the maximum number of subfigures
-        savepath: the save path of figure
         style: the background style, default, seaborn-dark, ggplot, bmh, seaborn-bright
         colors: take the color from this list in turn for each line
         alpha: transparency
@@ -60,20 +57,14 @@ class PlotMax:
     """
 
     def __init__(self, 
-                 figsize=(16,5), 
-                 figtitle='', 
                  capacity=1, 
-                 savepath='', 
                  count_cut=100, 
                  style='seaborn-bright',
                  colors=None,
                  alpha=None,
                  fname=None):
-        self.figtitle = figtitle
-        self.figsize = figsize
         self.capacity = capacity
         self.data_list = []
-        self.savepath = savepath
         self.count_cut = count_cut
 
         if isinstance(colors, list):
@@ -91,9 +82,6 @@ class PlotMax:
 
         plt.style.use(style)
 
-        if len(savepath) > 0:
-            plt.switch_backend('agg')
-
     def get_ax(self, first='col'):
         """
         lay out, find the ax for recent subplot
@@ -266,7 +254,10 @@ class PlotMax:
              anchor=(0, 1),
              cut=None,
              legend_loc="upper left",
-             first='col'):
+             first='col',
+             figsize=(16,5),
+             savepath=''
+             ):
         """
         build a figure frame to show data list
         args:
@@ -286,6 +277,8 @@ class PlotMax:
             cut: cut the x-axis data list
             legend_loc: the default legend location
             first: the first direction to put subfigure, 'col'|'row'
+            figsize: the size of figure like (16,5)
+            savepath: the save path
         """
 
         # calculate the number of columns and rows
@@ -297,6 +290,9 @@ class PlotMax:
         else:
             self.nrows, self.ncols = self.get_row_col(graph_count)
 
+        if len(savepath) > 0:
+            plt.switch_backend('agg')
+
         if ncols is not None:
             self.ncols = ncols
             self.nrows = nrows
@@ -304,7 +300,7 @@ class PlotMax:
 
         # initialize figure
         _, self.axes = plt.subplots(nrows=self.nrows, ncols=self.ncols, 
-                                    figsize=(self.figsize[0] * self.ncols, self.figsize[1] * self.nrows))
+                                    figsize=(figsize[0] * self.ncols, figsize[1] * self.nrows))
         plt.subplots_adjust(wspace=wspace, hspace=hspace)
 
         # initialize the middle variables
@@ -434,7 +430,7 @@ class PlotMax:
             else:
                 if interval > 1:
                     ax.set_xticklabels(xlabels_str)
-            
+
             if grid:
                 ax.xaxis.grid(True, which='major', linestyle='--', color='k') 
                 ax.yaxis.grid(True, which='major', linestyle='--', color='k') 
@@ -455,9 +451,9 @@ class PlotMax:
                 
         plt.suptitle(main_title, fontsize=fontsize, fontproperties=self.myfont)
 
-        if graph_count > self.count_cut or len(self.savepath) > 0:
+        if graph_count > self.count_cut or len(savepath) > 0:
             print('save figure')
-            plt.savefig(self.savepath, bbox_inches = 'tight', dpi=dpi, pad_inches=0.0)
+            plt.savefig(savepath, bbox_inches = 'tight', dpi=dpi, pad_inches=0.0)
             plt.close()
         else:
             plt.axis('tight')
@@ -465,7 +461,7 @@ class PlotMax:
 
         if d['dist']:
             _, self.axes = plt.subplots(nrows=self.nrows, ncols=self.ncols, 
-                                    figsize=(self.figsize[0] * self.ncols, self.figsize[1] * self.nrows))
+                                    figsize=(figsize[0] * self.ncols, figsize[1] * self.nrows))
             for i in range(len(extend_dist)):
                 d = self.data_list[i]
                 ax = self.get_ax(first)
